![Upload Python Package](https://github.com/vitalij555/bitops/workflows/Upload%20Python%20Package/badge.svg)
[![PyPi version](https://img.shields.io/pypi/v/bitops.svg?style=flat-square) ](https://pypi.python.org/pypi/bitops) [![Supported Python versions](https://img.shields.io/pypi/pyversions/bitops.svg?style=flat-square) ](https://pypi.org/project/bitops) [![License](https://img.shields.io/pypi/l/bitops.svg?style=flat-square) ](https://choosealicense.com/licenses) [![Downloads](https://pepy.tech/badge/bitops)](https://pepy.tech/project/bitops) [![codecov](https://codecov.io/gh/vitalij555/bitops/branch/master/graph/badge.svg)](https://codecov.io/gh/vitalij555/bitops)



# Simple module for bit operations in a byte (get, set, etc..)